scxpand.mlp.mlp\_losses
=======================

.. automodule:: scxpand.mlp.mlp_losses

   
   .. rubric:: Functions

   .. autosummary::
   
      compute_batch_loss
      compute_total_nn_loss
      create_loss_function
      should_use_soft_loss
   